/******************************************************************************/
/*
 * eRIC Example Pulse Width Modulation V1.1(PWM)
 * Low Power Radio Solutions
 * March 2016
 * Built with CCS V6.1.2.00015
 * This example will explain pulse width modulation (PWM) technique. Pin19 is set as PWM1 and duty cyle is slowly increased and decrease continoulsy.
 * Since Pin19 is conneceted to LED4 on dev board, the led brightness changes Up/Down. If at anytime Pin16 or Pin17 is pressed , the Pin18(set as PWM2)
 * Led3 brightness is changed according to pressing on Pin16 and PIn17. Pressing Pin17 increases Pin18 brightness and Pin16 decreases the brightness.
 * When Pin16 and Pin17 are pressed together, the function returns back again changing Pin19 brightness continously.
 *
 */

/******************************************************************************/
//Version V1.1
#include<cc430f5137.h>
#include "eRIC.h"
#include <stdio.h>
#include <string.h>


void BrightControl();

int j =0;

int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled

	eRIC_SetCpuFrequency(1000000);    //Set Cpu frequency as 1mhz

	Pin19_FunctionPWM1();             //Assign Pin19 to PWM1
	Pin18_FunctionPWM2();             //Assign Pin18 to PWM2
	Pin17_SetAsInput();               //Set Pin17 as input
	Pin17_PullDownEnable();
	Pin16_SetAsInput();               //Set Pin16 as input
	Pin16_PullDownEnable();
	eRIC_PWM_Setup(eRICPWM_Cs_32k,eRICPWM_DIV_1,eRICPWM_UpMode,512);    //Set PWM with 32k clock source and Upmode and period being 512.
	int i=0;
	while(1)
	{
		i = 0;
		while(i<512)
		{
			if(Pin16_Read() ||Pin17_Read())  //If either of Pins is pressed, jump to bright control function
			{
				eRIC_PWM1_DutyCycle(0,eRICPWM_OutputMode_Reset_Set);  //Reset PWM1 at 0 and set at period(512). Almost off.
				BrightControl();
			}
			eRIC_PWM1_DutyCycle(i++,eRICPWM_OutputMode_Set_Reset);  //Set PWM1 at i and reset at period
			eRIC_Delay(10);
		}
		eRIC_Delay(2000);
		i = 0;
		while(i<512)
		{
			if(Pin16_Read() ||Pin17_Read()) //If either of Pins is pressed, jump to bright control function
			{
				eRIC_PWM1_DutyCycle(0,eRICPWM_OutputMode_Reset_Set);  //Reset PWM1 at 0 and set at period(512). Almost off.
				BrightControl();
			}
			eRIC_PWM1_DutyCycle(i++,eRICPWM_OutputMode_Reset_Set);  //Reset PWM1 at i and set at period
			eRIC_Delay(10);
		}
		eRIC_Delay(2000); //2sec delay
	}//end of while(1)
}//end of main

void BrightControl()
{
	if(j>512)
		j=0;
	while(1)
	{
	while(Pin17_Read())
	{
		if(Pin17_Read()&&Pin16_Read())           //If both Pin16 and Pin17 are pressed
		{
			while(Pin16_Read()||Pin17_Read());  //wait untill both pins are low
			eRIC_PWM2_DutyCycle(0,eRICPWM_OutputMode_Reset_Set);
			return;
		}
		if(j<=512)
			eRIC_PWM2_DutyCycle(j++,eRICPWM_OutputMode_Reset_Set);
		eRIC_Delay(5);
	}
	while(Pin16_Read())
	{
		if(Pin17_Read()&&Pin16_Read())          //If both Pin16 and Pin17 are pressed
		{
			while(Pin16_Read()||Pin17_Read()); //wait untill both pins are low
			eRIC_PWM2_DutyCycle(0,eRICPWM_OutputMode_Reset_Set);
			return;
		}
		if(j>=0)
			eRIC_PWM2_DutyCycle(j--,eRICPWM_OutputMode_Reset_Set);
		eRIC_Delay(5);
	}
	}//end of while(1)
}

void eRIC_RfDataReceivedInterrupt()   //Add code here to deal with  available received data..This is triggered when interrupt is enabled and a packet is received
{
}

